===============
Display Options
===============

Display options commands are used to store settings that specify how assemblies and parts are to be displayed and how annotations are to be rendered in a particular viewport.


Classes
-------

AssemblyDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.AssemblyDisplayOptions.AssemblyDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

BCDisplayOptions
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.BCDisplayOptions.BCDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstraintDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.ConstraintDisplayOptions.ConstraintDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

EngineeringFeatureDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.EngineeringFeatureDisplayOptions.EngineeringFeatureDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

GeometricRestrictionDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.GeometricRestrictionDisplayOptions.GeometricRestrictionDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

GeometryDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.GeometryDisplayOptions.GeometryDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

GraphicsInfo
~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.GraphicsInfo.GraphicsInfo
    :members:
    :special-members: __init__

    .. autoclasstoc::

GraphicsOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.GraphicsOptions.GraphicsOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

InteractionDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.InteractionDisplayOptions.InteractionDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

Light
~~~~~

.. autoclass:: abaqus.DisplayOptions.Light.Light
    :members:
    :special-members: __init__

    .. autoclasstoc::

LightArray
~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.LightArray.LightArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

LightOptions
~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.LightOptions.LightOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

LoadDisplayOptions
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.LoadDisplayOptions.LoadDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshDisplayOptions
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.MeshDisplayOptions.MeshDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

OptimizationTaskDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.OptimizationTaskDisplayOptions.OptimizationTaskDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

PartDisplayOptions
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.PartDisplayOptions.PartDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

PredefinedFieldDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.PredefinedFieldDisplayOptions.PredefinedFieldDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

StopConditionDisplayOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.StopConditionDisplayOptions.StopConditionDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

SymbolDisplayOptions
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.SymbolDisplayOptions.SymbolDisplayOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

ViewportAnnotationOptions
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.DisplayOptions.ViewportAnnotationOptions.ViewportAnnotationOptions
    :members:
    :special-members: __init__